.title Navigation

The navigation system is used to determine how to go from one world position to another as a serie of waypoints.

## Navigation Mesh

In order to perform a navigation query you need a navigation mesh. A navigation mesh is compiled by the assets compiler from a definition file with the `.pathfinding` extension.

A pathfinding definition is a JSON file with the following structure:
